@@ -1,12 +1,15 @@
 # encoding:UTF-8
+import sys
 import ctypes
+from ctypes import *
+from datetime import datetime
+from typing import List, Optional
 
 from taos.cinterface import IS_V3
 from taos.constants import FieldType
 from taos.precision import PrecisionEnum, PrecisionError
-from datetime import datetime
-from ctypes import *
-import sys
+from taos.field import get_tz
+from taos.bind_base import datetime_to_timestamp
 
 _datetime_epoch = datetime.utcfromtimestamp(0)
 
@@ -111,14 +114,14 @@ class TaosBind(ctypes.Structure):
                 if precision == PrecisionEnum.Milliseconds:
                     ts = int(round((value - _datetime_epoch).total_seconds() * 1000))
                 elif precision == PrecisionEnum.Microseconds:
-                    ts = int(round((value - _datetime_epoch).total_seconds() * 10000000))
+                    ts = int(round((value - _datetime_epoch).total_seconds() * 1000000))
                 else:
                     raise PrecisionError("datetime do not support nanosecond precision")
             elif type(value) is float:
                 if precision == PrecisionEnum.Milliseconds:
                     ts = int(round(value * 1000))
                 elif precision == PrecisionEnum.Microseconds:
-                    ts = int(round(value * 10000000))
+                    ts = int(round(value * 1000000))
                 else:
                     raise PrecisionError("time float do not support nanosecond precision")
             elif isinstance(value, int) and not isinstance(value, bool):
@@ -126,9 +129,9 @@ class TaosBind(ctypes.Structure):
             elif isinstance(value, str):
                 value = datetime.fromisoformat(value)
                 if precision == PrecisionEnum.Milliseconds:
-                    ts = int(round(value * 1000))
+                    ts = int(round((value - _datetime_epoch).total_seconds() * 1000))
                 elif precision == PrecisionEnum.Microseconds:
-                    ts = int(round(value * 10000000))
+                    ts = int(round((value - _datetime_epoch).total_seconds() * 1000000))
                 else:
                     raise PrecisionError("datetime do not support nanosecond precision")
             self.buffer = cast(pointer(c_int64(ts)), c_void_p)
@@ -202,38 +205,8 @@ class TaosBind(ctypes.Structure):
             self.buffer = cast(pointer(c_uint64(value)), c_void_p)
             self.buffer_length = sizeof(c_uint64)
 
-
-def _datetime_to_timestamp(value, precision):
-    # type: (datetime | float | int | str | c_int64, PrecisionEnum) -> c_int64
-    if value is None:
-        return FieldType.C_BIGINT_NULL
-    if type(value) is datetime:
-        if precision == PrecisionEnum.Milliseconds:
-            return int(round((value - _datetime_epoch).total_seconds() * 1000))
-        elif precision == PrecisionEnum.Microseconds:
-            return int(round((value - _datetime_epoch).total_seconds() * 10000000))
-        else:
-            raise PrecisionError("datetime do not support nanosecond precision")
-    elif type(value) is float:
-        if precision == PrecisionEnum.Milliseconds:
-            return int(round(value * 1000))
-        elif precision == PrecisionEnum.Microseconds:
-            return int(round(value * 10000000))
-        else:
-            raise PrecisionError("time float do not support nanosecond precision")
-    elif isinstance(value, int) and not isinstance(value, bool):
-        return c_int64(value)
-    elif isinstance(value, str):
-        value = datetime.fromisoformat(value)
-        if precision == PrecisionEnum.Milliseconds:
-            return int(round(value * 1000))
-        elif precision == PrecisionEnum.Microseconds:
-            return int(round(value * 10000000))
-        else:
-            raise PrecisionError("datetime do not support nanosecond precision")
-    elif isinstance(value, c_int64):
-        return value
-    return FieldType.C_BIGINT_NULL
+    def varchar(self, value):
+        self.binary(value)
 
 
 class TaosMultiBind(ctypes.Structure):
@@ -371,7 +344,7 @@ class TaosMultiBind(ctypes.Structure):
         self.num = len(values)
         self.is_null = cast((c_char * len(values))(*[1 if value is None else 0 for value in values]), c_char_p)
 
-    def _str_to_buffer(self, values):
+    def _str_to_buffer(self, values, encode=True):
         self.num = len(values)
         is_null = [1 if v is None else 0 for v in values]
         self.is_null = cast((c_byte * self.num)(*is_null), c_char_p)
@@ -386,10 +359,15 @@ class TaosMultiBind(ctypes.Structure):
                 create_string_buffer(b, buffer_length) if b is not None else create_string_buffer(buffer_length)
                 for b in _bytes
             ]
-            buffer_all = b''.join(v[:] for v in buffers)
+            buffer_all = b"".join(v[:] for v in buffers)
             self.buffer = cast(c_char_p(buffer_all), c_void_p)
         else:
-            _bytes = [value.encode("utf-8") if value is not None else None for value in values]
+            _bytes = []
+            if encode:
+                _bytes = [value.encode("utf-8") if value is not None else None for value in values]
+            else:
+                _bytes = [bytes(value) if value is not None else None for value in values]
+
             buffer_length = max(len(b) for b in _bytes if b is not None)
             self.buffer = cast(
                 c_char_p(
@@ -420,7 +398,7 @@ class TaosMultiBind(ctypes.Structure):
             buffer = cast(values, c_void_p)
         except:
             buffer_type = c_int64 * len(values)
-            buffer = buffer_type(*[_datetime_to_timestamp(value, precision) for value in values])
+            buffer = buffer_type(*[datetime_to_timestamp(value, precision) for value in values])
 
         self.buffer_type = FieldType.C_TIMESTAMP
         self.buffer = cast(buffer, c_void_p)
@@ -514,6 +492,24 @@ class TaosMultiBind(ctypes.Structure):
         self.num = len(values)
         self.is_null = cast((c_char * len(values))(*[1 if value is None else 0 for value in values]), c_char_p)
 
+    def varchar(self, values):
+        if type(values) is not tuple and type(values) is not list:
+            values = tuple([values])
+        self.buffer_type = FieldType.C_VARCHAR
+        self._str_to_buffer(values)
+
+    def varbinary(self, values):
+        if type(values) is not tuple and type(values) is not list:
+            values = tuple([values])
+        self.buffer_type = FieldType.C_VARBINARY
+        self._str_to_buffer(values, False)
+
+    def geometry(self, values):
+        if type(values) is not tuple and type(values) is not list:
+            values = tuple([values])
+        self.buffer_type = FieldType.C_GEOMETRY
+        self._str_to_buffer(values, False)
+
 
 def new_bind_param():
     # type: () -> TaosBind
