@@ -4,7 +4,7 @@
 """
 
 import ctypes, struct
-
+from enum import Enum
 
 class FieldType(object):
     """TDengine Field Types"""
@@ -27,6 +27,11 @@ class FieldType(object):
     C_INT_UNSIGNED = 13
     C_BIGINT_UNSIGNED = 14
     C_JSON = 15
+    C_VARBINARY = 16
+    C_DECIMAL = 17
+    C_BLOB = 18
+    C_GEOMETRY = 20
+    C_DECIMAL64 = 21
     # NULL value definition
     # NOTE: These values should change according to C definition in tsdb.h
     C_BOOL_NULL = 0x02
@@ -46,3 +51,14 @@ class FieldType(object):
     C_TIMESTAMP_MICRO = 1
     C_TIMESTAMP_NANO = 2
     C_TIMESTAMP_UNKNOWN = 3
+
+class TSDB_OPTION_CONNECTION(Enum):
+    TSDB_OPTION_CONNECTION_CLEAR = -1     # means clear all option in this connection
+    TSDB_OPTION_CONNECTION_CHARSET = 0    # charset, Same as the scope supported by the system
+    TSDB_OPTION_CONNECTION_TIMEZONE = 1   # timezone, Same as the scope supported by the system
+    TSDB_OPTION_CONNECTION_USER_IP = 2    # user ip
+    TSDB_OPTION_CONNECTION_USER_APP = 3   # user app, max lengthe is 23, truncated if longer than 23
+    TSDB_MAX_OPTIONS_CONNECTION = 4
+
+class TSDB_CONNECTIONS_MODE(Enum):
+    TSDB_CONNECTIONS_MODE_BI = 0
\ No newline at end of file
