@@ -1,4 +1,6 @@
 # encoding:UTF-8
+from typing import Optional
+
 from taos.cinterface import *
 from taos.error import *
 from taos.constants import FieldType
@@ -25,7 +27,7 @@ class TaosCursor(object):
             .execute*() produced (for DQL statements like SELECT) or affected
     """
 
-    def __init__(self, connection=None):
+    def __init__(self, connection=None, decode_binary=True):
         self._description = []
         self._rowcount = -1
         self._connection = None
@@ -36,6 +38,7 @@ class TaosCursor(object):
         self._block_iter = 0
         self._affected_rows = 0
         self._logfile = ""
+        self.decode_binary = decode_binary
 
         if connection is not None:
             self._connection = connection
@@ -54,8 +57,7 @@ class TaosCursor(object):
             raise OperationalError("Invalid use of fetch iterator")
 
         if self._block_rows <= self._block_iter:
-            block, self._block_rows = taos_fetch_row(
-                self._result, self._fields)
+            block, self._block_rows = taos_fetch_row(self._result, self._fields, decode_binary=self.decode_binary)
             if self._block_rows == 0:
                 raise StopIteration
             self._block = list(map(tuple, zip(*block)))
@@ -104,8 +106,7 @@ class TaosCursor(object):
 
         return True
 
-    def execute(self, operation, params=None):
-        # type: (str, Any) -> int|None
+    def execute(self, operation, params=None, req_id: Optional[int] = None):
         """Prepare and execute a database operation (query or command)."""
         if not operation:
             return None
@@ -124,7 +125,10 @@ class TaosCursor(object):
         # querySeqNum += 1
         # localSeqNum = querySeqNum # avoid race condition
         # print("   >> Exec Query ({}): {}".format(localSeqNum, str(stmt)))
-        self._result = taos_query(self._connection._conn, stmt)
+        if req_id is None:
+            self._result = taos_query(self._connection._conn, stmt)
+        else:
+            self._result = taos_query_with_reqid(self._connection._conn, stmt, req_id)
         # print("   << Query ({}) Exec Done".format(localSeqNum))
         if self._logfile:
             with open(self._logfile, "a", encoding="utf-8") as logfile:
@@ -139,10 +143,27 @@ class TaosCursor(object):
             self._fields = taos_fetch_fields(self._result)
             return self._handle_result()
 
-    def executemany(self, operation, seq_of_parameters):
-        """Prepare a database operation (query or command) and then execute it against all parameter sequences or mappings found in the sequence seq_of_parameters."""
-        self.execute(operation)
-        pass
+    def execute_many(self, operation, data_list, req_id: Optional[int] = None):
+        """
+        Prepare a database operation (query or command) and then execute it against all parameter sequences or mappings
+        found in the sequence seq_of_parameters.
+        """
+        sql = operation
+        flag = True
+        affected_rows = 0
+        for line in data_list:
+            if isinstance(line, dict):
+                flag = False
+                # print(f'execute: {sql.format(**line)}')
+                affected_rows += self.execute(sql.format(**line), req_id=req_id)
+            elif isinstance(line, list):
+                sql += f' {tuple(line)} '
+            elif isinstance(line, tuple):
+                sql += f' {line} '
+        if flag:
+            # print(f'execute_many: {sql}')
+            affected_rows += self.execute(sql, req_id=req_id)
+        return affected_rows
 
     def fetchone(self):
         """Fetch the next row of a query result set, returning a single sequence, or None when no more data is available."""
@@ -197,6 +218,9 @@ class TaosCursor(object):
         if dataType.upper() == "JSON":
             if self._description[col][1] == FieldType.C_JSON:
                 return True
+        if dataType.upper() == "VARBINARY":
+            if self._description[col][1] == FieldType.C_VARBINARY:
+                return True
 
         return False
 
@@ -208,7 +232,7 @@ class TaosCursor(object):
         buffer = [[] for i in range(len(self._fields))]
         self._rowcount = 0
         while True:
-            block, num_of_rows = taos_fetch_row(self._result, self._fields)
+            block, num_of_rows = taos_fetch_row(self._result, self._fields, decode_binary=self.decode_binary)
             errno = taos_errno(self._result)
             if errno != 0:
                 raise ProgrammingError(taos_errstr(self._result), errno)
@@ -227,7 +251,7 @@ class TaosCursor(object):
         buffer = [[] for i in range(len(fields))]
         self._rowcount = 0
         while True:
-            block, num_of_rows = taos_fetch_block(self._result, self._fields)
+            block, num_of_rows = taos_fetch_block(self._result, self._fields, decode_binary=self.decode_binary)
             errno = taos_errno(self._result)
             if errno != 0:
                 raise ProgrammingError(taos_errstr(self._result), errno)
