@@ -2,6 +2,10 @@
 """Python exceptions
 """
 
+class ErrMsg :
+    STMT2_NULL           = "stmt2 object is null"
+    STMT2_COUNT_NOTMATCH = "count is not match"
+
 
 class Error(Exception):
     def __init__(self, msg=None, errno=0xffff):
@@ -99,18 +103,6 @@ class SchemalessError(DatabaseError):
     #     return self.affected_rows
 
 
-class StatementError(DatabaseError):
-    """Exception raised in STMT API."""
-
-    pass
-
-
-class ResultError(DatabaseError):
-    """Result related APIs."""
-
-    pass
-
-
 class LinesError(DatabaseError):
     """taos_insert_lines errors."""
 
@@ -121,3 +113,9 @@ class TmqError(DatabaseError):
     """Exception raise in TMQ API"""
 
     pass
+
+class DataTypeAndRangeError(Error):
+    """Exception raise in check value datatype and range error API"""
+
+    pass
+    
\ No newline at end of file
